This project has adopted the [Microsoft Open Source Code of Conduct](https://opensource.microsoft.com/codeofconduct/). For more information see the [Code of Conduct FAQ](https://opensource.microsoft.com/codeofconduct/faq/) or contact [opencode@microsoft.com](mailto:opencode@microsoft.com) with any additional questions or comments.

# azure-c-shared-utility/adapters

This directory contains files for adapting specific devices to work with the Azure C Shared Utility.

### This location is deprecated

The files in this directory will eventually be moved to new locations in the
 [azure-c-shared-utility/pal](https://github.com/Azure/azure-c-shared-utility/tree/master/pal) 
directory.

### Where did that file go?

Files related to adapting the Azure IoT C SDK to specific devices are being moved to new locations
within the [azure-c-shared-utility/pal](https://github.com/Azure/azure-c-shared-utility/tree/master/pal) 
directory and its subfolders.

### Porting to new devices

Instructions for porting the Azure IoT C SDK to new devices are located
[here](https://github.com/Azure/azure-c-shared-utility/blob/pal-porting/devdoc/porting_guide.md).
